addTimestamp method

  1. @override
Future<String?> addTimestamp(
  1. String path, {
  2. double? latitude,
  3. double? longitude,
})
override

Embeds a date/time timestamp and location metadata onto the image at path and returns the absolute path of the updated image file.

Implementation

@override
Future<String?> addTimestamp(String path, {double? latitude, double? longitude}) async {
  final timestampedPath = await methodChannel.invokeMethod<String>(
    'addTimestamp',
    {
      'path': path,
      'latitude': latitude,
      'longitude': longitude,
    },
  );
  return timestampedPath;
}