addTimestamp method

Future<String?> addTimestamp(
  1. String path, {
  2. double? latitude,
  3. double? longitude,
})

Embeds a date/time timestamp and location metadata onto the image at path and returns the absolute path of the updated image file.

Implementation

Future<String?> addTimestamp(String path, {double? latitude, double? longitude}) {
  throw UnimplementedError('addTimestamp() has not been implemented.');
}