MethodChannelUnifiedFaceCamera class
An implementation of UnifiedFaceCameraPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- UnifiedFaceCameraPlatform
- MethodChannelUnifiedFaceCamera
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addTimestamp(
String path, {double? latitude, double? longitude}) → Future< String?> -
Embeds a date/time timestamp and location metadata onto the image at
pathand returns the absolute path of the updated image file.override -
checkCameraPermission(
) → Future< bool> -
Checks if the camera permission is granted.
override
-
checkLocationPermission(
) → Future< bool> -
Checks if the location permission is granted.
override
-
getLocation(
) → Future< Map< String, double> ?> -
Fetches the current location (latitude and longitude).
Returns a map with keys 'latitude' and 'longitude', or null if not available/denied.
override
-
getPlatformVersion(
) → Future< String?> -
Returns the platform version string (e.g. "Android 13").
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
requestCameraPermission(
) → Future< bool> -
Requests the camera permission and returns whether it was granted.
override
-
requestLocationPermission(
) → Future< bool> -
Requests the location permission and returns whether it was granted.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited