addTimestamp method
Embeds a date/time timestamp and location metadata onto the image at path
and returns the absolute path of the updated image file.
Implementation
@override
Future<String?> addTimestamp(String path, {double? latitude, double? longitude}) async {
final timestampedPath = await methodChannel.invokeMethod<String>(
'addTimestamp',
{
'path': path,
'latitude': latitude,
'longitude': longitude,
},
);
return timestampedPath;
}